@@ -77,30 +77,38 @@ from mh_universal_functions._version import __version__
 module_logger = logging.getLogger('__name__')
 
 
-def database_update_universal(mysql_const, row, table, value, id1, id1_value, id2, id2_value):
+# Database write operation from a MySQL database
+def database_update_universal(def_mysql_const,
+                              def_row,
+                              def_table,
+                              def_value,
+                              def_id1,
+                              def_id1_value,
+                              def_id2,
+                              def_id2_value):
     """
     Database update operation on an existing MySQL database.
-    :param mysql_const: list, contains the following data:
-                              - active: boolean, access the database
-                              - host: str, name of the server hosting the MySQL database
-                              - database: str, name of the MySQL database
-                              - user: str, name of the user of the MySQL database
-                              - password: str, password of the user
-    :param row: str, name of the row of the database table which is intended to be updated
-    :param table: str, name of the table which row is intended to be updated
-    :param value: str, value with which the row is intended to be updated
-    :param id1: str, first identification of the table to be updated
-    :param id1_value: str, first identification value of the table to be updated
-    :param id2: str, second identification of the table to be updated
-    :param id2_value: str, second identification value of the table to be updated
+    :param def_mysql_const: list, contains the following data:
+                            - active: boolean, access the database
+                            - host: str, name of the server hosting the MySQL database
+                            - database: str, name of the MySQL database
+                            - user: str, name of the user of the MySQL database
+                            - password: str, password of the user
+    :param def_row: str, name of the row of the database table which is intended to be updated
+    :param def_table: str, name of the table which row is intended to be updated
+    :param def_value: str, value with which the row is intended to be updated
+    :param def_id1: str, first identification of the table to be updated
+    :param def_id1_value: str, first identification value of the table to be updated
+    :param def_id2: str, second identification of the table to be updated
+    :param def_id2_value: str, second identification value of the table to be updated
     :returns: bool, true if database was successfully updated
     """
 
-    active = mysql_const[0]
-    host = mysql_const[1]
-    database = mysql_const[2]
-    user = mysql_const[3]
-    password = mysql_const[4]
+    active = def_mysql_const[0]
+    host = def_mysql_const[1]
+    database = def_mysql_const[2]
+    user = def_mysql_const[3]
+    password = def_mysql_const[4]
 
     if not active:
         return False
@@ -112,43 +120,49 @@ def database_update_universal(mysql_const, row, table, value, id1, id1_value, id
             user=user, passwd=password
         )
         cursor = db_connection.cursor()
-        sql_statement_part1 = "UPDATE " + table + " SET " + row + "='" + str(value) + "' WHERE " + id1 + "='" +\
-                              str(id1_value) + "'"
-        sql_statement_part2 = " AND " + id2 + "='" + str(id2_value) + "'"
+        sql_statement_part1 = 'UPDATE ' + def_table + ' SET ' + def_row + '="' + str(def_value) +\
+                              '" WHERE ' + def_id1 + '="' + str(def_id1_value) + '"'
+        sql_statement_part2 = ' AND ' + def_id2 + '="' + str(def_id2_value) + '"'
 
-        if id2 == "":
+        if def_id2 == "":
             sql_statement = sql_statement_part1
         else:
             sql_statement = sql_statement_part1 + sql_statement_part2
 
-        module_logger.info("Update of table: '" + table + "' in database: '" + database +
+        module_logger.info("Update of table: '" + def_table + "' in database: '" + database +
                            "' using sql statement: '" + sql_statement + "'")
 
         cursor.execute(sql_statement)
         db_connection.commit()
         db_connection.close()
         return True
-    except Exception as error_detail1:
-        module_logger.error("Cannot connect do database, error_detail1 = '" + str(error_detail1) + "'")
+    except Exception as error_detail:
+        module_logger.error("Cannot connect do database, error_detail = '" + str(error_detail) + "'")
         return False
 
 
 # Database read operation from a MySQL database
-def database_read(mysql_const, row, table, id1, id1_value, id2, id2_value):
+def database_read(def_mysql_const,
+                  def_row,
+                  def_table,
+                  def_id1,
+                  def_id1_value,
+                  def_id2,
+                  def_id2_value):
     """
     Read from MySQL database.
-    :param mysql_const: list, contains the following data:
-                              - active: boolean, name of the server hosting the MySQL database
-                              - host: str, name of the server hosting the MySQL database
-                              - database: str, name of the MySQL database
-                              - user: str, name of the user of the MySQL database
-                              - password: str, password of the user
-    :param row: str, row of the database to be read from
-    :param table: str, table of the database to be read from
-    :param id1: str, first identification of the table to be updated
-    :param id1_value: str, first identification value of the table to be updated
-    :param id2: str, second identification of the table to be updated
-    :param id2_value: str, second identification value of the table to be updated
+    :param def_mysql_const: list, contains the following data:
+                            - active: boolean, name of the server hosting the MySQL database
+                            - host: str, name of the server hosting the MySQL database
+                            - database: str, name of the MySQL database
+                            - user: str, name of the user of the MySQL database
+                            - password: str, password of the user
+    :param def_row: str, row of the database to be read from
+    :param def_table: str, table of the database to be read from
+    :param def_id1: str, first identification of the table to be updated
+    :param def_id1_value: str, first identification value of the table to be updated
+    :param def_id2: str, second identification of the table to be updated
+    :param def_id2_value: str, second identification value of the table to be updated
     :returns: value: various, value of selected database row entry
 
     Example queries:
@@ -157,11 +171,11 @@ def database_read(mysql_const, row, table, id1, id1_value, id2, id2_value):
     test3 = database_read("motion_stream_text", "pir_controls", "pir_controls_id", "1", "", "")
     """
 
-    active = mysql_const[0]
-    host = mysql_const[1]
-    database = mysql_const[2]
-    user = mysql_const[3]
-    password = mysql_const[4]
+    active = def_mysql_const[0]
+    host = def_mysql_const[1]
+    database = def_mysql_const[2]
+    user = def_mysql_const[3]
+    password = def_mysql_const[4]
 
     if not active:
         return False
@@ -173,25 +187,25 @@ def database_read(mysql_const, row, table, id1, id1_value, id2, id2_value):
             user=user, passwd=password
         )
         cursor = db_connection.cursor()
-        sql_statement_basis = "SELECT " + row + " FROM " + table
-        id1_statement = id1 + " = " + id1_value
-        id2_statement = id2 + " = " + id2_value
-        if id1 is not "" and id2 is not "":
-            sql_statement = sql_statement_basis + " WHERE " + id1_statement + " AND " + id2_statement
-        elif id1 is "" and id2 is "":
+        sql_statement_basis = 'SELECT ' + def_row + ' FROM ' + def_table
+        id1_statement = def_id1 + ' = "' + def_id1_value + '"'
+        id2_statement = def_id2 + ' = "' + def_id2_value + '"'
+        if def_id1 is not "" and def_id2 is not "":
+            sql_statement = sql_statement_basis + ' WHERE ' + id1_statement + ' AND ' + id2_statement
+        elif def_id1 is "" and def_id2 is "":
             sql_statement = sql_statement_basis
-        elif id1 is "":
-            sql_statement = sql_statement_basis + " WHERE " + id2_statement
-        elif id2 is "":
-            sql_statement = sql_statement_basis + " WHERE " + id1_statement
+        elif def_id1 is "":
+            sql_statement = sql_statement_basis + ' WHERE ' + id2_statement
+        elif def_id2 is "":
+            sql_statement = sql_statement_basis + ' WHERE ' + id1_statement
         else:
             return "error"
         cursor.execute(sql_statement)
         value = cursor.fetchone()[0]
         db_connection.close()
         return value
-    except Exception as error_detail1:
-        module_logger.error("Cannot connect to MySQL database, error_detail2 = '" + str(error_detail1) + "'")
+    except Exception as error_detail:
+        module_logger.error("Cannot connect to MySQL database, error_detail = '" + str(error_detail) + "'")
         return "error"
 
 
